"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const inquirer_1 = __importDefault(require("inquirer"));
const utils_1 = require("./utils");
const PROFILE_REGEX = /^\[(?:[^\s]*?\s)?(.*)\]$/;
const getProfileName = line => line.match(PROFILE_REGEX)[1];
const parseConf = conf => ({
    profiles: conf.split('\n')
        .filter(s => s.startsWith('['))
        .map(getProfileName)
});
const getProfiles = () => {
    let conf;
    try {
        conf = fs_1.default.readFileSync(`${os_1.default.homedir()}/.aws/config`, { encoding: 'utf8' });
    }
    catch (err) {
        return ['default'];
    }
    const { profiles } = parseConf(conf);
    return profiles.includes('default') ? profiles : ['default'].concat(profiles);
};
exports.init = (conf) => {
    return [
        {
            type: 'list',
            name: 'awsProfile',
            message: 'Select your aws profile',
            choices: getProfiles()
                .map(profile => ({
                name: profile,
                value: profile
            }))
                .concat([
                new inquirer_1.default.Separator(),
                {
                    name: 'Other (specify)',
                    value: null
                }
            ]),
        },
        {
            type: 'input',
            name: 'awsProfile',
            message: 'profile',
            when: answers => !answers.profile
        },
        {
            type: 'list',
            name: 'stackName',
            choices: Promise.resolve().then(() => {
                const stackInfos = conf.getStacks();
                return stackInfos.map(({ name }) => name);
            })
        },
        {
            type: 'input',
            name: 'local',
            message: 'Do you have a local development environment, a clone of https://github.com/tradle/serverless? If yes, enter the path',
            validate: local => {
                if (!utils_1.isValidProjectPath(local)) {
                    return 'Provided path doesn\'t contain a serverless.yml';
                }
                return true;
            }
        }
    ];
};
inquirer_1.default.prompt(getPrompts())
    .then(console.log, console.error);
//# sourceMappingURL=init-prompts.js.map