"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const os_1 = tslib_1.__importDefault(require("os"));
const yn_1 = tslib_1.__importDefault(require("yn"));
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const utils_1 = require("./utils");
const models_cloud_1 = tslib_1.__importDefault(require("@tradle/models-cloud"));
const regions = models_cloud_1.default['tradle.cloud.AWSRegion'].enum.map(({ id, title }) => ({
    name: title,
    value: id.replace(/[.]/g, '-')
}));
const PROFILE_REGEX = /^\[(?:[^\s]*?\s)?(.*)\]$/;
const getProfileName = line => line.match(PROFILE_REGEX)[1];
const parseConf = conf => ({
    profiles: conf.split('\n')
        .filter(s => s.startsWith('['))
        .map(getProfileName)
});
const getProfiles = () => {
    let conf;
    try {
        conf = fs_1.default.readFileSync(`${os_1.default.homedir()}/.aws/credentials`, { encoding: 'utf8' });
    }
    catch (err) {
        return ['default'];
    }
    const { profiles } = parseConf(conf);
    return profiles.includes('default') ? profiles : ['default'].concat(profiles);
};
exports.init = (conf) => {
    const defaultWhen = answers => answers.overwriteEnv !== false;
    return inquirer_1.default.prompt([
        {
            type: 'confirm',
            name: 'overwriteEnv',
            message: 'This will overwrite your .env file',
            when: () => fs_1.default.existsSync('./.env')
        },
        {
            type: 'list',
            name: 'region',
            message: 'Which AWS region is your deployment in?',
            choices: regions
        },
        {
            type: 'list',
            name: 'awsProfile',
            message: 'Select your aws profile',
            when: defaultWhen,
            choices: getProfiles()
                .map(profile => ({
                name: profile,
                value: profile
            }))
                .concat([
                new inquirer_1.default.Separator(),
                {
                    name: 'Other (specify)',
                    value: null
                }
            ]),
        },
        {
            type: 'input',
            name: 'awsProfile',
            message: 'profile',
            when: answers => answers.overwriteEnv && !answers.awsProfile
        },
        {
            type: 'list',
            name: 'stack',
            message: 'Which Tradle stack will you be configuring?',
            when: defaultWhen,
            choices: ({ region, awsProfile }) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                const stackInfos = yield conf.getStacks({
                    profile: awsProfile,
                    region
                });
                return stackInfos.map(({ name, id }) => ({
                    name,
                    value: { name, id }
                }));
            })
        },
        {
            type: 'input',
            name: 'projectPath',
            message: '(optional) Enter the path to your local development environment (a clone of https://github.com/tradle/serverless). Press <Enter> to skip',
            when: defaultWhen,
            validate: local => {
                if (yn_1.default(local) && !utils_1.isValidProjectPath(local)) {
                    return 'Provided path doesn\'t contain a serverless.yml';
                }
                return true;
            }
        }
    ]);
};
exports.fn = (conf, message) => {
    return inquirer_1.default.prompt([
        {
            type: 'list',
            name: 'fn',
            message,
            choices: conf.getFunctions
        }
    ])
        .then(({ fn }) => fn);
};
exports.confirm = (message) => {
    return inquirer_1.default.prompt([
        {
            type: 'confirm',
            name: 'confirm',
            message
        }
    ])
        .then(({ confirm }) => confirm);
};
//# sourceMappingURL=prompts.js.map